package ai.nextbillion.octant.engine;

import android.app.PendingIntent;
import android.content.Context;
import android.location.Location;
import android.os.Looper;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.baidu.location.BDAbstractLocationListener;
import com.baidu.location.BDLocation;
import com.baidu.location.LocationClient;
import com.baidu.location.LocationClientOption;

public class BaiduLocationEngineImpl implements LocationEngineImpl<BDAbstractLocationListener> {

    private final LocationClient locationClient;

    public BaiduLocationEngineImpl(Context context) {
        locationClient = new LocationClient(context.getApplicationContext());
    }

    @NonNull
    @Override
    public BDAbstractLocationListener createListener(LocationEngineCallback<LocationEngineResult> callback) {
        return new BaiduLocationEngineCallbackTransport(callback);
    }

    @Override
    public void getLastLocation(@NonNull LocationEngineCallback<LocationEngineResult> callback) throws SecurityException {
        BDLocation bdLocation = locationClient.getLastKnownLocation();
        if (bdLocation != null && bdLocation.getLocType() == 161) {
            Location location = convert(bdLocation);
            callback.onSuccess(LocationEngineResult.create(location));
            return;
        }
        callback.onFailure(new Exception("Last location unavailable"));
    }

    @Override
    public void requestLocationUpdates(@NonNull LocationEngineRequest request, @NonNull BDAbstractLocationListener listener, @Nullable Looper looper) throws SecurityException {
        int interval = (int) request.getInterval();
        LocationClientOption option = config(interval);
        locationClient.setLocOption(option);
        locationClient.registerLocationListener(listener);
        if (!locationClient.isStarted()) {
            locationClient.start();
        }
    }

    @Override
    public void requestLocationUpdates(@NonNull LocationEngineRequest request, @NonNull PendingIntent pendingIntent) throws SecurityException {

    }

    @Override
    public void removeLocationUpdates(BDAbstractLocationListener listener) {
        locationClient.unRegisterLocationListener(listener);
        if (locationClient.isStarted()) {
            locationClient.stop();
        }
    }

    @Override
    public void removeLocationUpdates(PendingIntent pendingIntent) {

    }

    static final class BaiduLocationEngineCallbackTransport extends BDAbstractLocationListener {

        private final LocationEngineCallback<LocationEngineResult> callback;

        public BaiduLocationEngineCallbackTransport(LocationEngineCallback<LocationEngineResult> callback) {
            this.callback = callback;
        }

        @Override
        public void onReceiveLocation(BDLocation bdLocation) {
            if (bdLocation != null && bdLocation.getLocType() == 161) {
                callback.onSuccess(LocationEngineResult.create(convert(bdLocation)));
            } else if (bdLocation != null) {
                callback.onFailure(new Exception("Baidu LocType = " + bdLocation.getLocType()));
            }
        }
    }

    static Location convert(BDLocation bdLocation) {
        Location location = new Location("Baidu");
        location.setLatitude(bdLocation.getLatitude());
        location.setLongitude(bdLocation.getLongitude());
        location.setTime(System.currentTimeMillis());
        return location;
    }

    LocationClientOption config(int interval) {
        LocationClientOption option = new LocationClientOption();
//        option.setCoorType("BD09");
        option.setEnableSimulateGps(true);
        option.setScanSpan(interval);
        option.setOpenGps(true);
        option.setLocationNotify(true);
        option.setIgnoreKillProcess(false);
        option.SetIgnoreCacheException(false);
        return option;
    }

    @Override
    public String toString() {
        return "BaiduLocationEngineImpl{" +
                "locationClient=" + locationClient +
                '}';
    }
}
