package ai.nextbillion.octant.engine;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.telephony.TelephonyManager;
import android.text.TextUtils;

import java.util.Locale;

public class LocationUtils {

    public static boolean useBaiduLocationEngine(Context context) {
        boolean isUserInChina = isUserInChina(context);
        boolean hasBaiduKey = hasBaiduKey(context);
        return isUserInChina && hasBaiduKey;
    }

    ///////////////////////////////////////////////////////////////////////////
    // Region
    ///////////////////////////////////////////////////////////////////////////

    public static boolean isUserInChina(Context context) {
        boolean isCNService = isCNService(context);
        if (!isCNService) {
            return isChinaSimCard(context);
        }
        return isCNService;
    }

    public static boolean isCNService(Context context) {
        TelephonyManager tm = (TelephonyManager) context.getSystemService(Context.TELEPHONY_SERVICE);
        String countryIso = tm.getSimCountryIso();
        boolean isCN = false;
        if (!TextUtils.isEmpty(countryIso)) {
            countryIso = countryIso.toUpperCase(Locale.US);
            if (countryIso.contains("CN")) {
                isCN = true;
            }
        }
        return isCN;
    }

    public static boolean isChinaSimCard(Context c) {
        String mcc = getSimOperator(c);
        if (isOperatorEmpty(mcc)) {
            return false;
        } else {
            return mcc.startsWith("460");
        }
    }

    private static boolean isOperatorEmpty(String operator) {
        if (operator == null) {
            return true;
        }

        return operator.equals("") || operator.toLowerCase(Locale.US).contains("null");
    }

    private static String getSimOperator(Context context) {
        TelephonyManager tm = (TelephonyManager) context.getSystemService(Context.TELEPHONY_SERVICE);
        try {
            return tm.getSimOperator();
        } catch (Exception ignored) {
        }
        return null;

    }

    ///////////////////////////////////////////////////////////////////////////
    //
    ///////////////////////////////////////////////////////////////////////////

    public static boolean hasBaiduKey(Context context) {
        try {
            ApplicationInfo app = context.getPackageManager().getApplicationInfo(context.getPackageName(), PackageManager.GET_META_DATA);
            Bundle bundle = app.metaData;
            String baiduKey = bundle.getString("com.baidu.lbsapi.API_KEY");
            return !TextUtils.isEmpty(baiduKey);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return false;
    }
}
